from dash import Dash, html, dcc, dash_table, Input, Output, callback
import dash_bootstrap_components as dbc
import dash

dash.register_page(__name__, "/")

# layout = html.Div(
#     [
#         html.H1("Home"),
#         dcc.Input(id="filename-input", type="text", placeholder="Enter filename name"),
#         dbc.Button("Load", id="filename-input-button", n_clicks=0),
#         html.Div(id="home-output"),
#         dbc.Button("Refresh List", id="home-refresh-list-button", n_clicks=0),
#         dash_table.DataTable(
#             id="home-recipes-list-table",
#             columns=[
#                 {"name": "File Name", "id": "file_name"},
#                 #   {'name':'Posix', 'id':'posix_friendly'}
#             ],
#             data=[],
#             style_table={"width": "300px"},
#             style_cell={"textAlign": "left"},
#         ),
#     ]
# )

layout = html.Div(
    [
        html.H1("Home"),
        # dbc.Row(
        #     [
        #         dbc.Col(
        #             dcc.Input(
        #                 id="filename-input",
        #                 type="text",
        #                 placeholder="Enter file name",
        #                 className="form-control",
        #             ),
        #             width=6,
        #         ),
        #         dbc.Col(
        #             dbc.Button(
        #                 "Load",
        #                 id="filename-input-button",
        #                 n_clicks=0,
        #                 color="primary",
        #                 className="btn btn-primary",
        #             ),
        #             width=2,
        #         ),
        #     ],
        #     className="mb-3",
        # ),
        # dbc.Alert(
        #     id="home-load-file-alert",
        #     color="success",
        #     is_open=False,
        #     # fade=True,
        #     className="mb-3",
        # ),
        # dbc.Row(
        #     [
        #         dbc.Col(
        #             dbc.Button(
        #                 "Refresh List",
        #                 id="home-refresh-list-button",
        #                 n_clicks=0,
        #                 color="secondary",
        #                 className="btn btn-secondary mb-3",
        #             ),
        #             width=2,
        #         )
        #     ]
        # ),
        # dbc.Row(
        #     [
        #         dbc.Col(
        #             dash_table.DataTable(
        #                 id="home-recipes-list-table",
        #                 columns=[
        #                     {"name": "File Name", "id": "file_name"},
        #                     {"name": "Posix Compatible", "id": "posix_friendly"},
        #                     {"name": "Viewer Compatible", "id": "dash_friendly"},
        #                     {"name": "Python Code Available", "id": "python_code"},
        #                 ],
        #                 data=[],
        #                 style_table={"width": "100%"},
        #                 style_cell={"textAlign": "left"},
        #                 style_header={"fontWeight": "bold"},
        #                 page_current=0,
        #                 page_size=10,
        #                 style_data_conditional=[
        #                     {
        #                         "if": {
        #                             "column_id": "posix_friendly",
        #                             "filter_query": "{posix_friendly} contains true",
        #                         },
        #                         "backgroundColor": "#b7e8c4",
        #                         "color": "black",
        #                     },
        #                     {
        #                         "if": {
        #                             "column_id": "posix_friendly",
        #                             "filter_query": "{posix_friendly} contains false",
        #                         },
        #                         "backgroundColor": "#e8b7b7",
        #                         "color": "black",
        #                     },
        #                     {
        #                         "if": {
        #                             "column_id": "dash_friendly",
        #                             "filter_query": "{dash_friendly} contains true",
        #                         },
        #                         "backgroundColor": "#b7e8c4",
        #                         "color": "black",
        #                     },
        #                     {
        #                         "if": {
        #                             "column_id": "dash_friendly",
        #                             "filter_query": "{dash_friendly} contains false",
        #                         },
        #                         "backgroundColor": "#e8b7b7",
        #                         "color": "black",
        #                     },
        #                     {
        #                         "if": {
        #                             "column_id": "python_code",
        #                             "filter_query": "{python_code} contains true",
        #                         },
        #                         "backgroundColor": "#b7e8c4",
        #                         "color": "black",
        #                     },
        #                     {
        #                         "if": {
        #                             "column_id": "python_code",
        #                             "filter_query": "{python_code} contains false",
        #                         },
        #                         "backgroundColor": "#e8b7b7",
        #                         "color": "black",
        #                     },
        #                 ],
        #             ),
        #             width=10,
        #         )
        #     ]
        # ),
    ],
    className="container",
)



from dash import Dash, html, dcc, dash_table, callback, Input, Output, State
import dash_bootstrap_components as dbc
import dash

dash.register_page(__name__, path="/view-recipe", name="View Recipe", title="View Recipe")

layout = html.Div(
    [
        html.H1("View Recipe"),
        html.Div(
            [
                dbc.Alert(
                    id="view-recipe-alert",
                    color="success",
                    is_open=False,
                    fade=True,
                    className="mb-3",
                ),
                html.Div(
                    [
                        html.H2("Devices"),
                        dbc.ButtonGroup(
                            [
                                dbc.Button("Refresh", id="refresh-button1", n_clicks=0),
                                dbc.Button("Add device", id="add-device-button"),
                                dbc.Button("Edit", id="edit-device-button"),
                                dbc.Button("Delete", id="delete-device-button"),
                            ],
                            className="mb-3",
                        ),
                        dbc.Modal(
                            [
                                dbc.ModalHeader(dbc.ModalTitle("Editor"), close_button=False),
                                dbc.ModalBody(
                                    [
                                        dcc.Textarea(
                                            id="device-json-editor",
                                            style={
                                                "width": "100%",
                                                "height": "200px",
                                                "fontFamily": "monospace",
                                                "backgroundColor": "#f5f5f5",
                                                "border": "1px solid #ccc",
                                                "padding": "10px",
                                                "color": "#333",
                                            },
                                        ),
                                        html.Div(
                                            id="edit-device-error",
                                            style={"color": "red"},
                                        ),
                                        html.Div(
                                            id="edit-device-serial-ports-info",
                                        ),
                                    ]
                                ),
                                dbc.ModalFooter(dbc.Button("Save", id="save-device-editor")),
                            ],
                            id="device-editor-modal",
                            keyboard=False,
                            backdrop="static",
                        ),
                        dbc.Modal(
                            [
                                dbc.ModalHeader(dbc.ModalTitle("Add Device")),
                                dbc.ModalBody(
                                    [
                                        dcc.Dropdown(
                                            id="add-device-dropdown",
                                            options=[],
                                            value=None,
                                            className="mb-2",
                                        ),
                                        dcc.Textarea(
                                            id="add-device-json-editor",
                                            style={
                                                "width": "100%",
                                                "height": "200px",
                                                "fontFamily": "monospace",
                                                "backgroundColor": "#f5f5f5",
                                                "border": "1px solid #ccc",
                                                "padding": "10px",
                                                "color": "#333",
                                            },
                                        ),
                                        html.Div(
                                            id="add-device-error",
                                            style={"color": "red", "display": "none"},
                                        ),
                                        html.Div(
                                            id="add-device-serial-ports-info",
                                        ),
                                    ]
                                ),
                                dbc.ModalFooter(dbc.Button("Add", id="add-device-editor")),
                            ],
                            id="device-add-modal",
                            keyboard=False,
                            backdrop="static",
                        ),
                        html.Div(
                            children=[dash_table.DataTable(id="devices-table")],
                            id="devices-table-div",
                        ),
                    ],
                    className="table-container mb-3",
                ),
                html.Div(
                    [
                        html.H2("Commands"),
                        dbc.ButtonGroup(
                            [
                                dbc.Button("Refresh", id="refresh-button2", n_clicks=0),
                                dbc.Button("Add command", id="add-command-open-modal-button"),
                                dbc.Button("Edit", id="edit-command-button"),
                                dbc.Button("Delete", id="delete-command-button"),
                            ],
                            className="mb-3",
                        ),
                        dbc.Modal(
                            [
                                dbc.ModalHeader(dbc.ModalTitle("Editor"), close_button=False),
                                dbc.ModalBody(
                                    [
                                        dcc.Textarea(
                                            id="command-json-editor",
                                            style={
                                                "width": "100%",
                                                "height": "200px",
                                                "fontFamily": "monospace",
                                                "backgroundColor": "#f5f5f5",
                                                "border": "1px solid #ccc",
                                                "padding": "10px",
                                                "color": "#333",
                                            },
                                        ),
                                        html.Div(
                                            id="edit-command-error",
                                            style={"color": "red"},
                                        ),
                                    ]
                                ),
                                dbc.ModalFooter(dbc.Button("Save", id="save-command-editor")),
                            ],
                            id="command-editor-modal",
                            keyboard=False,
                            backdrop="static",
                        ),
                        dbc.Modal(
                            [
                                dbc.ModalHeader(dbc.ModalTitle("Add Command")),
                                dbc.ModalBody(
                                    [
                                        dcc.Dropdown(
                                            id="view-recipe-add-command-device-dropdown",
                                            options=[],
                                            value=None,
                                        ),
                                        dcc.Dropdown(
                                            id="view-recipe-add-command-command-dropdown",
                                            options=[],
                                            value=None,
                                            className="mb-2",
                                        ),
                                        dcc.Textarea(
                                            id="view-recipe-add-command-json-editor",
                                            style={
                                                "width": "100%",
                                                "height": "200px",
                                                "fontFamily": "monospace",
                                                "backgroundColor": "#f5f5f5",
                                                "border": "1px solid #ccc",
                                                "padding": "10px",
                                                "color": "#333",
                                            },
                                        ),
                                        html.Div(
                                            id="add-command-error",
                                            style={"color": "red"},
                                        ),
                                    ]
                                ),
                                dbc.ModalFooter(
                                    dbc.Button("Add", id="view-recipe-add-command-editor")
                                ),
                            ],
                            id="view-recipe-command-add-modal",
                            keyboard=False,
                            backdrop="static",
                        ),
                        html.Div(
                            children=[dash_table.DataTable(id="commands-table")],
                            id="commands-table-div",
                        ),
                        # dbc.Accordion(
                        #     [
                        #         dbc.AccordionItem(
                        #             "item1", title="Item 1", item_id="item1"
                        #         )
                        #     ],
                        #     id="commands-accordion",
                        #     # start_collapsed=True,
                        #     style={"display": "none"},
                        # ),
                    ],
                    className="table-container mb-3",
                ),
                html.Div(
                    [
                        html.H2("Execution Options"),
                        dbc.Row(
                            [
                                dbc.Row(
                                    [
                                        dbc.Col(
                                            [
                                                html.H5("Default Execution Record Name"),
                                                dbc.Col(
                                                    [
                                                        dbc.Input(
                                                            id="view-recipe-execution-options-default-execution-record-name",
                                                        )
                                                    ]
                                                ),
                                            ]
                                        ),
                                        dbc.Col(
                                            [
                                                html.H5("Output Files"),
                                                dbc.Textarea(
                                                    id="view-recipe-execution-options-output-files",
                                                    placeholder="Enter one filename with extension per line",
                                                ),
                                            ]
                                        ),
                                    ],
                                    className="mb-3",
                                ),
                            ]
                        ),
                        dbc.Button(
                            "Save Options",
                            id="view-recipe-execution-options-save-button",
                            n_clicks=0,
                            className="mb-3",
                        ),
                        dbc.Label(
                            "Execution Options Saved",
                            id="view-recipe-execution-options-saved-label",
                            style={"display": "none"},
                        ),
                    ],
                    className="table-container mb-5",
                )
                # html.Div(
                #     [
                #         html.H2("Command Iterations"),
                #         html.Button("Refresh", id="refresh-button3", n_clicks=0),
                #         html.Div(id="table-container3"),
                #     ],
                #     className="table-container",
                # ),
            ],
            className="tables-container",
        ),
    ],
    className="container",
)


@callback(
    Output("device-editor-modal", "is_open"),
    [Input("edit-device-button", "n_clicks"), Input("save-device-editor", "n_clicks")],
    [State("device-editor-modal", "is_open")],
)
def toggle_device_editor_modal(n1, n2, is_open):
    if n1 or n2:
        return not is_open
    return is_open


@callback(
    Output("device-add-modal", "is_open"),
    [Input("add-device-button", "n_clicks"), Input("add-device-editor", "n_clicks")],
    [State("device-add-modal", "is_open")],
)
def toggle_device_add_modal(n1, n2, is_open):
    if n1 or n2:
        return not is_open
    return is_open


@callback(
    Output("command-editor-modal", "is_open"),
    [
        Input("edit-command-button", "n_clicks"),
        Input("save-command-editor", "n_clicks"),
    ],
    [State("command-editor-modal", "is_open")],
)
def toggle_command_editor_modal(n1, n2, is_open):
    if n1 or n2:
        return not is_open
    return is_open



from dash import Dash, html, dcc, dash_table, Input, Output, State, callback
import dash_bootstrap_components as dbc
import dash
import dash_ace

dash.register_page(__name__, path="/edit-recipe", title="Edit Recipe", name="Edit Recipe")

layout = html.Div(
    [
        html.H1("Edit Recipe Code"),
        html.Div(
            [
                html.Div(
                    [
                        dbc.Alert("Alert", id="ace-editor-alert", is_open=False, duration=500),
                        dbc.ButtonGroup(
                            [
                                dbc.Button("Fill editor", id="refresh-button-ace", n_clicks=0),
                                dbc.Button("Add device", id="add-device-button-ace"),
                                dbc.Button("Add command", id="add-command-button-ace"),
                                dbc.Button(
                                    "Execute and save yaml",
                                    id="execute-and-save-button",
                                    n_clicks=0,
                                ),
                            ],
                            className="mb-3",
                        ),
                        dbc.Modal(
                            [
                                dbc.ModalHeader(dbc.ModalTitle("Add Device")),
                                dbc.ModalBody(
                                    [
                                        dcc.Dropdown(
                                            id="add-device-dropdown-ace",
                                            options=[],
                                            value=None,
                                        ),
                                    ]
                                ),
                                dbc.ModalFooter(dbc.Button("Add", id="add-device-editor-ace")),
                            ],
                            id="device-add-modal-ace",
                            keyboard=False,
                            backdrop="static",
                        ),
                        dbc.Modal(
                            [
                                dbc.ModalHeader(dbc.ModalTitle("Add Command")),
                                dbc.ModalBody(
                                    [
                                        dcc.Dropdown(
                                            id="add-command-device-dropdown-ace",
                                            options=[],
                                            value=None,
                                        ),
                                    ]
                                ),
                                dbc.ModalBody(
                                    [
                                        dcc.Dropdown(
                                            id="add-command-command-dropdown-ace",
                                            options=[],
                                            value=None,
                                        ),
                                    ]
                                ),
                                dbc.ModalFooter(dbc.Button("Add", id="add-command-editor-ace")),
                            ],
                            id="command-add-modal-ace",
                            keyboard=False,
                            backdrop="static",
                        ),
                        dash_ace.DashAceEditor(
                            id="ace-recipe-editor",
                            mode="python",
                            enableBasicAutocompletion=True,
                            enableLiveAutocompletion=True,
                            theme="github",
                            wrapEnabled=True,
                            style={"width": "100%", "height": "550px"},
                            cursorStart=333,
                        ),
                    ],
                    className="table-container",
                ),
            ],
            className="tables-container",
        ),
    ],
    className="container",
)


@callback(
    Output("command-add-modal-ace", "is_open"),
    [
        Input("add-command-editor-ace", "n_clicks"),
        Input("add-command-button-ace", "n_clicks"),
    ],
    State("command-add-modal-ace", "is_open"),
)
def toggle_command_add_modal_ace(n1, n2, is_open):
    if n1 or n2:
        return not is_open
    return is_open


@callback(
    Output("device-add-modal-ace", "is_open"),
    [
        Input("add-device-button-ace", "n_clicks"),
        Input("add-device-editor-ace", "n_clicks"),
    ],
    [State("device-add-modal-ace", "is_open")],
)
def toggle_device_add_modal_ace(n1, n2, is_open):
    if n1 or n2:
        return not is_open
    return is_open



from dash import Dash, html, dcc, dash_table
import dash_bootstrap_components as dbc
import dash


dash.register_page(__name__, path="/data", title="Recipe Document", name="Recipe Document")

layout = html.Div(
    [
        html.H1("View Recipe Document"),
        dbc.Button("Load data", id="load-data-button", n_clicks=0, className="mb-3"),
        # dcc.Textarea(
        #     id="data-output", readOnly=True, style={"width": "100%", "height": 0}
        # ),
        # html.Div(id="data-output-div"),
        html.Div(id="data-output-div2"),
    ],
    className="container",
)



from dash import Dash, html, dcc, dash_table, callback, Input, Output, State
import dash_bootstrap_components as dbc
import dash

dash.register_page(
    __name__, path="/database", title="Database Browser", name="Database Browser"
)

layout = html.Div(
    [
        html.H1("Database Browser", className="mb-3"),
        dcc.Interval(id="interval-database", interval=500000, n_intervals=0),
        dbc.Row(
            [
                dbc.Col(
                    [
                        dcc.Dropdown(
                            id="database-db-dropdown",
                            options=[],
                            value=None,
                            className="mb-3",
                            placeholder="Select a database",
                        ),
                        dbc.Col([], id="database-db-data"),
                    ]
                ),
                dbc.Col(
                    [
                        dcc.Dropdown(
                            id="database-collection-dropdown",
                            options=[],
                            value=None,
                            className="mb-3",
                            disabled=True,
                            placeholder="Select a collection",
                        ),
                        dbc.Col([], id="database-collection-schema"),
                    ]
                ),
                dbc.Col(
                    [
                        dcc.Dropdown(
                            id="database-document-dropdown",
                            options=[],
                            value=None,
                            className="mb-3",
                            disabled=True,
                            placeholder="Select a document",
                        ),
                        dbc.Col([], id="database-document-viewer"),
                    ]
                ),
            ]
        ),
    ],
    className="container",
)



from dash import Dash, html, dcc, dash_table, Input, Output, callback
import dash_bootstrap_components as dbc
import dash

dash.register_page(__name__, path="/load-recipe", title="Load Recipe", name="Load Recipe")


layout = html.Div(
    [
        html.H1("Load Recipe"),
        dbc.Row(
            [
                dbc.Col(
                    dcc.Input(
                        id="filename-input",
                        type="text",
                        placeholder="Enter file name",
                        className="form-control",
                    ),
                    width=6,
                ),
                dbc.Col(
                    dbc.Button(
                        "Load",
                        id="filename-input-button",
                        n_clicks=0,
                        color="primary",
                        className="btn btn-primary",
                    ),
                    width=2,
                ),
            ],
            className="mb-3",
        ),
        dbc.Alert(
            id="home-load-file-alert",
            color="success",
            is_open=False,
            # fade=True,
            className="mb-3",
        ),
        dbc.Row(
            [
                dbc.Col(
                    [
                        dbc.Button(
                            "Refresh List",
                            id="home-refresh-list-button",
                            n_clicks=0,
                            color="secondary",
                            className="btn btn-secondary mb-3",
                        ),
                    ],
                    width=2,
                ),
                dbc.Col(
                    [
                        dbc.Button(
                            "Create New Recipe",
                            id="home-create-new-recipe-button",
                            n_clicks=0,
                        )
                    ],
                ),
            ]
        ),
        dbc.Row(
            [
                dbc.Col(
                    dash_table.DataTable(
                        id="home-recipes-list-table",
                        columns=[
                            {"name": "Recipe Name", "id": "file_name"},
                            {"name": "Posix Compatible", "id": "posix_friendly"},
                            {"name": "Viewer Compatible", "id": "dash_friendly"},
                            {"name": "Python Code Available", "id": "python_code"},
                        ],
                        data=[],
                        style_table={"width": "100%"},
                        style_cell={"textAlign": "left"},
                        style_header={"fontWeight": "bold"},
                        page_current=0,
                        page_size=10,
                        style_data_conditional=[
                            {
                                "if": {
                                    "column_id": "posix_friendly",
                                    "filter_query": "{posix_friendly} contains true",
                                },
                                "backgroundColor": "#b7e8c4",
                                "color": "black",
                            },
                            {
                                "if": {
                                    "column_id": "posix_friendly",
                                    "filter_query": "{posix_friendly} contains false",
                                },
                                "backgroundColor": "#e8b7b7",
                                "color": "black",
                            },
                            {
                                "if": {
                                    "column_id": "dash_friendly",
                                    "filter_query": "{dash_friendly} contains true",
                                },
                                "backgroundColor": "#b7e8c4",
                                "color": "black",
                            },
                            {
                                "if": {
                                    "column_id": "dash_friendly",
                                    "filter_query": "{dash_friendly} contains false",
                                },
                                "backgroundColor": "#e8b7b7",
                                "color": "black",
                            },
                            {
                                "if": {
                                    "column_id": "python_code",
                                    "filter_query": "{python_code} contains true",
                                },
                                "backgroundColor": "#b7e8c4",
                                "color": "black",
                            },
                            {
                                "if": {
                                    "column_id": "python_code",
                                    "filter_query": "{python_code} contains false",
                                },
                                "backgroundColor": "#e8b7b7",
                                "color": "black",
                            },
                        ],
                    ),
                    width=10,
                )
            ]
        ),
    ],
    className="container",
)
